@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,9 +36,10 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.documentai_v1.types import document
-from google.cloud.documentai_v1.types import document_processor_service
-from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.documentai_v1.types import document, document_processor_service
+
+from .transports.base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
 from .transports.grpc import DocumentProcessorServiceGrpcTransport
 from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
 
@@ -58,7 +59,8 @@ class DocumentProcessorServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = DocumentProcessorServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[DocumentProcessorServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -169,10 +171,16 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return self._transport
 
     @staticmethod
-    def human_review_config_path(project: str, location: str, processor: str,) -> str:
+    def human_review_config_path(
+        project: str,
+        location: str,
+        processor: str,
+    ) -> str:
         """Returns a fully-qualified human_review_config string."""
         return "projects/{project}/locations/{location}/processors/{processor}/humanReviewConfig".format(
-            project=project, location=location, processor=processor,
+            project=project,
+            location=location,
+            processor=processor,
         )
 
     @staticmethod
@@ -185,10 +193,16 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def processor_path(project: str, location: str, processor: str,) -> str:
+    def processor_path(
+        project: str,
+        location: str,
+        processor: str,
+    ) -> str:
         """Returns a fully-qualified processor string."""
         return "projects/{project}/locations/{location}/processors/{processor}".format(
-            project=project, location=location, processor=processor,
+            project=project,
+            location=location,
+            processor=processor,
         )
 
     @staticmethod
@@ -201,7 +215,9 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -214,9 +230,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -225,9 +245,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -236,9 +260,13 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -247,10 +275,14 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -513,7 +545,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -530,7 +567,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1
@@ -612,7 +648,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -637,7 +678,6 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         r"""Send a document for Human Review. The input document
         should be processed by the specified processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1
@@ -726,7 +766,12 @@ class DocumentProcessorServiceClient(metaclass=DocumentProcessorServiceClientMet
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
