@@ -13,9 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import math
 import os
 
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
+import math
+
 from google.api_core import (
     future,
     gapic_v1,
@@ -36,7 +44,6 @@ from google.oauth2 import service_account
 from google.rpc import status_pb2  # type: ignore
 import grpc
 from grpc.experimental import aio
-import mock
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
 
